Protei.MediaGateway
===================

====== =================================
Vendor `Protei <http://www.protei.ru/>`_
OS     
====== =================================

Protei.MediaGateway profile supports Протей MTU/MAK/ITG families of media gateways

Tested Equipment
----------------
.. supported:: Protei.MediaGateway
